@@ -1,4 +1,4 @@
-# Copyright (c) 2018, Adrian Dusa
+# Copyright (c) 2019, Adrian Dusa
 # All rights reserved.
 # 
 # Redistribution and use in source and binary forms, with or without
@@ -24,11 +24,11 @@
 # SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 `setColnames` <- function(matrix, colnames) {
-    invisible(.Call("setColnames", matrix, colnames))
+    invisible(.Call("C_setColnames", matrix, colnames))
 }
 `setRownames` <- function(matrix, rownames) {
-    invisible(.Call("setRownames", matrix, rownames))
+    invisible(.Call("C_setRownames", matrix, rownames))
 }
 `setDimnames` <- function(matrix, nameslist) {
-    invisible(.Call("setDimnames", matrix, nameslist))
+    invisible(.Call("C_setDimnames", matrix, nameslist))
 }
