@@ -25,9 +25,9 @@
 
 `minimize` <-
 function(input, include = "", exclude = NULL, dir.exp = "",
-         pi.cons = 0, pi.depth = 0, sol.cons = 0, sol.cov = 1, sol.depth = 0,
-         min.pin = FALSE, row.dom = FALSE, all.sol = FALSE,
-         details = FALSE, use.tilde = FALSE, method = "CCubes", ...) {
+        pi.cons = 0, pi.depth = 0, sol.cons = 0, sol.cov = 1, sol.depth = 0,
+        min.pin = FALSE, row.dom = FALSE, all.sol = FALSE,
+        details = FALSE, use.tilde = FALSE, method = "CCubes", ...) {
     metacall <- match.call()
     other.args <- list(...)
     back.args <- c("outcome", "conditions", "n.cut", "incl.cut", "complete", "show.cases", sort.by = "", "use.letters", "inf.test",
@@ -78,8 +78,8 @@ function(input, include = "", exclude = NULL, dir.exp = "",
             }
             input <- as.data.frame(input)
             for (i in seq(ncol(input))) {
-                if (possibleNumeric(input[, i])) {
-                    input[, i] <- asNumeric(input[, i])
+                if (admisc::possibleNumeric(input[, i])) {
+                    input[, i] <- admisc::asNumeric(input[, i])
                 }
             }
         }
@@ -96,13 +96,13 @@ function(input, include = "", exclude = NULL, dir.exp = "",
         }
     }
     if (is.character(explain) & !identical(explain, "1")) {
-        explain <- splitstr(explain)
+        explain <- admisc::splitstr(explain)
     }
     if (is.character(include) & !identical(include, "")) {
-        include <- splitstr(include)
+        include <- admisc::splitstr(include)
     }
     if (is.character(outcome) & !identical(outcome, "")) {
-        outcome <- splitstr(outcome)
+        outcome <- admisc::splitstr(outcome)
     }
     if (methods::is(input, "tt")) { 
         tt <- input
@@ -127,23 +127,16 @@ function(input, include = "", exclude = NULL, dir.exp = "",
         outcome <- toupper(outcome)
         outcome.copy <- outcome
         indata <- input 
-        if (tilde1st(outcome)) {
-            neg.out <- TRUE
-            outcome <- substring(outcome, 2)
-        }
-        if (!is.element(toupper(curlyBrackets(outcome, outside = TRUE)), colnames(input))) {
+        if (!is.element(toupper(admisc::curlyBrackets(admisc::notilde(outcome), outside = TRUE)), colnames(input))) {
             cat(enter)
             stop(simpleError(paste0("Inexisting outcome name.", enter, enter)))
         }
-        outcome.name <- ifelse (tilde1st(outcome), substring(outcome, 2), outcome)
-        if (grepl("\\{|\\}", outcome)) {
-            outcome.name <- curlyBrackets(outcome.name, outside = TRUE)
-        }
+        outcome.name <- admisc::curlyBrackets(admisc::notilde(outcome), outside = TRUE)
         if (identical(conditions, "")) {
             conditions <- names(input)[-which(names(input) == outcome.name)]
         }
         else {
-            conditions <- splitstr(conditions)
+            conditions <- admisc::splitstr(conditions)
         }
         input <- input[, c(conditions, outcome.name)]
         verify.minimize(input, outcome.name, conditions, explain, include, use.letters)
@@ -175,14 +168,14 @@ function(input, include = "", exclude = NULL, dir.exp = "",
     alreadyletters <- sum(nchar(colnames(recdata)[-ncol(recdata)])) == ncol(recdata) - 1
     tt$tt[seq(length(conditions))] <- as.data.frame(lapply(tt$tt[seq(length(conditions))], function(x) {
         x[x %in% c("-", "dc")] <- -1
-        return(asNumeric(x))
+        return(admisc::asNumeric(x))
     }))
     if (!is.null(exclude)) {
         if (identical(include, "")) {
             include <- "?"
         }
         else if (!grepl("?", include)) {
-            include <- c("?", splitstr(include))
+            include <- c("?", admisc::splitstr(include))
         }
     }
     pos.incl <- unique(c(explain, include)) 
@@ -229,8 +222,8 @@ function(input, include = "", exclude = NULL, dir.exp = "",
         neg.matrix <- rbind(neg.matrix, exclude + 1)
     }
     else if (is.vector(exclude)) {
-        if (possibleNumeric(exclude)) {
-            exclude <- asNumeric(exclude)
+        if (admisc::possibleNumeric(exclude)) {
+            exclude <- admisc::asNumeric(exclude)
         }
         if (is.character(exclude)) {
             exclude <- findRows(exclude, conditions, noflevels) 
@@ -252,14 +245,14 @@ function(input, include = "", exclude = NULL, dir.exp = "",
         stop(simpleError(paste0("Nothing to explain. Please check the truth table.", enter, enter)))
     }
     incl.rem <- is.element("?", include)
-    if (nrow(neg.matrix) == 0 & incl.rem) { 
+    if (nrow(neg.matrix) == 0 & incl.rem & !is.element("causalChain", names(other.args))) { 
         cat(enter)
         stop(simpleError(paste0("All truth table configurations are used, all conditions are minimized.\n",
                    "       Please check the truth table.", enter, enter)))
     }
     expressions <- pos.matrix
     recdata[, conditions] <- as.data.frame(lapply(recdata[, conditions, drop = FALSE], function(x) {
-        x[x %in% c("-", "?", "dc")] <- -1
+        x[is.element(x, c("-", "?", "dc"))] <- -1
         return(as.numeric(x))
     }))
     if (mv <- any(recdata[, seq(ncol(recdata) - 1)] > 1)) {
@@ -281,6 +274,9 @@ function(input, include = "", exclude = NULL, dir.exp = "",
         method <- "CCubes"
     }
     expressions <- .Call("C_QMC", expressions, noflevels, PACKAGE = "QCA")
+    if (is.element("simplify", names(other.args))) {
+        expressions <- admisc::sortExpressions(expressions)
+    }
     c.sol <- p.sol <- getSolution(expressions=expressions, mv=mv, use.tilde=use.tilde, collapse=collapse, inputt=inputt, row.dom=row.dom, initial=rownms, all.sol=all.sol, indata=indata, excl.matrix=excl.matrix, ...=...)
     if (incl.rem) {
         pos.matrix <- inputt
@@ -296,7 +292,7 @@ function(input, include = "", exclude = NULL, dir.exp = "",
                 expressions <- sort.int(findSupersets(pos.matrix, noflevels + 1))
             }
             expressions <- .Call("C_removeRedundants", expressions, noflevels, mbaseplus, PACKAGE = "QCA")
-            expressions <- sortExpressions(getRow(expressions, noflevels + 1))
+            expressions <- admisc::sortExpressions(getRow(expressions, noflevels + 1))
             setColnames(expressions, colnames(inputt))
         }
         else {
@@ -367,19 +363,18 @@ function(input, include = "", exclude = NULL, dir.exp = "",
             conds <- conditions[match(colnames(p.sol$reduced$expressions), LETTERS)]
         }
     }
-    if (length(output$solution) == 1) {
-        listIC <- pof(p.sol$reduced$expressions - 1, tt$options$outcome, indata, showc=TRUE, cases=expr.cases, neg.out=neg.out,
-                      relation = "sufficiency", conditions = conds)
-        listIC$options$show.cases <- show.cases
-    }
-    else {
-        listIC <- pof(p.sol$reduced$expressions - 1, tt$options$outcome, indata, showc=TRUE, cases=expr.cases, neg.out=neg.out,
-                      relation = "sufficiency", conditions = conds, solution.list=output$solution, essential=output$essential)
-        listIC$options$show.cases <- show.cases
+    poflist <- list(setms = paste(rownames(p.sol$reduced$expressions), collapse = "+"),
+                    outcome = tt$options$outcome, data = indata, neg.out = neg.out,
+                    use.letters = tt$options$use.letters, show.cases = TRUE, cases = expr.cases,
+                    conditions = conds, relation = "sufficiency", minimize = TRUE)
+    if (length(output$solution) > 1) {
+        poflist$solution.list <- output$solution
+        poflist$essential <- output$essential
     }
+    listIC <- do.call("pof", poflist)
+    listIC$options$show.cases <- show.cases
     output$pims <- listIC$pims
-    attr(output$pims, "conditions") <- conds
-    listIC$pims <- NULL
+    attr(output$pims, "conditions") <- conditions
     output$IC <- listIC
     output$numbers <- c(OUT1 = nofcases1, OUT0 = nofcases0, OUTC = nofcasesC, Total = nofcases1 + nofcases0 + nofcasesC)
     mtrx <- p.sol$mtrx[p.sol$all.PIs, , drop = FALSE]
@@ -421,17 +416,30 @@ function(input, include = "", exclude = NULL, dir.exp = "",
         })
         prettyNums <- formatC(seq(length(p.sol$solution.list[[1]])), digits = nchar(length(p.sol$solution.list[[1]])) - 1, flag = 0)
         if (!identical(dir.exp, "") & !identical(include, "") & !identical(c.sol$solution.list, NA)) {
-            dir.exp <- verify.dir.exp(recdata, outcome, conditions, noflevels, dir.exp)
-            EClist <- .Call("C_getEC", dir.exp, c.sol$expressions, c.sol$sol.matrix, p.sol$expressions, p.sol$sol.matrix, output$SA, PACKAGE = "QCA")
+            dir.exp <- verify.dir.exp(recdata, outcome, conditions, noflevels, dir.exp, enter)
+            if (!is.null(output$SA[[1]])) {
+                EClist <- .Call("C_getEC", dir.exp, c.sol$expressions, c.sol$sol.matrix, p.sol$expressions, p.sol$sol.matrix, output$SA, PACKAGE = "QCA")
+            }
+            else {
+                ECmat <- as.data.frame(matrix(ncol = length(conditions), nrow = 0))
+                colnames(ECmat) <- colnames(inputt)
+            }
             i.sol <- vector("list", ncol(c.sol$sol.matrix)*ncol(p.sol$sol.matrix))
             index <- 1
             for (c.s in seq(ncol(c.sol$sol.matrix))) {
                 for (p.s in seq(ncol(p.sol$sol.matrix))) {
                     names(i.sol)[index] <- paste("C", c.s, "P", p.s, sep = "")
-                    i.sol[[index]]$EC <- EClist[[index]]
-                    i.sol[[index]]$DC <- output$SA[[p.s]][setdiff(rownames(output$SA[[p.s]]), rownames(EClist[[index]])), , drop = FALSE]
-                    i.sol[[index]]$NSEC <- matrix(ncol = ncol(EClist[[index]]), nrow = 0)
-                    colnames(i.sol[[index]]$NSEC) <- colnames(EClist[[index]])
+                    if (is.null(output$SA[[1]])) {
+                        i.sol[[index]]$EC <- ECmat
+                        i.sol[[index]]$DC <- ECmat
+                        i.sol[[index]]$NSEC <- ECmat
+                    }
+                    else {
+                        i.sol[[index]]$EC <- EClist[[index]]
+                        i.sol[[index]]$DC <- output$SA[[p.s]][setdiff(rownames(output$SA[[p.s]]), rownames(EClist[[index]])), , drop = FALSE]
+                        i.sol[[index]]$NSEC <- matrix(ncol = ncol(EClist[[index]]), nrow = 0)
+                        colnames(i.sol[[index]]$NSEC) <- colnames(EClist[[index]])
+                    }
                     nsecs <- TRUE
                     while (nsecs) {
                         pos.matrix.i.sol <- unique(rbind(pos.matrix, i.sol[[index]]$EC + 1))
@@ -452,7 +460,7 @@ function(input, include = "", exclude = NULL, dir.exp = "",
                             }
                         }
                         pos.matrix.i.sol <- pos.matrix.i.sol[!tomit, , drop = FALSE]
-                        expressions <- .Call("C_QMC", pos.matrix.i.sol, noflevels, PACKAGE = "QCA") 
+                        expressions <- .Call("C_QMC", as.matrix(pos.matrix.i.sol), noflevels, PACKAGE = "QCA") 
                         i.sol.index <- getSolution(expressions=expressions, mv=mv, use.tilde=use.tilde, collapse=collapse, inputt=inputt, row.dom=row.dom, initial=rownms, all.sol=all.sol, indata=indata, ...=...)
                         i.sol.index$expressions <- i.sol.index$expressions[rowSums(i.sol.index$mtrx) > 0, , drop = FALSE]
                         if (nrow(i.sol[[index]]$EC) > 0) {
@@ -504,18 +512,16 @@ function(input, include = "", exclude = NULL, dir.exp = "",
                     for (l in seq(length(expr.cases))) {
                         expr.cases[l] <- paste(inputcases[which(mtrxlines[l, ])], collapse="; ")
                     }
-                    if (length(i.sol.index$solution.list[[1]]) == 1) {
-                        i.sol[[index]]$IC <- pof(i.sol.index$reduced$expressions - 1, outcome, indata, showc = TRUE,
-                                                 cases = expr.cases, relation = "sufficiency", neg.out = neg.out,
-                                                 conditions = conditions)
-                        i.sol[[index]]$IC$options$show.cases <- show.cases
-                    }
-                    else {
-                        i.sol[[index]]$IC <- pof(i.sol.index$reduced$expressions - 1, outcome, indata, showc = TRUE,
-                                                 cases = expr.cases, relation = "sufficiency", neg.out = neg.out, conditions = conditions,
-                                                 solution.list = i.sol.index$solution.list[[1]], essential = i.sol.index$solution.list[[2]])
-                        i.sol[[index]]$IC$options$show.cases <- show.cases
+                    poflist <- list(setms = paste(rownames(i.sol.index$reduced$expressions), collapse = "+"),
+                                    outcome = tt$options$outcome, data = indata, neg.out = neg.out,
+                                    use.letters = tt$options$use.letters, show.cases = TRUE, cases = expr.cases,
+                                    conditions = conditions, relation = "sufficiency", minimize = TRUE)
+                    if (length(i.sol.index$solution.list[[1]]) > 1) {
+                        poflist$solution.list <- i.sol.index$solution.list[[1]]
+                        poflist$essential <- i.sol.index$solution.list[[2]]
                     }
+                    i.sol[[index]]$IC <- do.call("pof", poflist)
+                    i.sol[[index]]$IC$options$show.cases <- show.cases
                     i.sol[[index]]$pims <- i.sol[[index]]$IC$pims
                     attr(i.sol[[index]]$pims, "conditions") <- conditions
                     i.sol[[index]]$IC$pims <- NULL
@@ -548,7 +554,7 @@ function(input, include = "", exclude = NULL, dir.exp = "",
 function(...) {
     allargs <- list(...)
     verify.mqca(allargs)
-    outcome <- splitstr(allargs$outcome)
+    outcome <- admisc::splitstr(allargs$outcome)
     minimize.list <- lapply(outcome, function(x) {
         allargs[["outcome"]] <- x
         return(do.call("minimize", allargs))
